<?php

########################################################################
# Extension Manager/Repository config file for ext "setup".
#
# Auto generated 23-02-2011 11:00
#
# Manual updates:
# Only the data in the array - everything else is removed by next
# writing. "version" and "dependencies" must not be touched!
########################################################################

$EM_CONF[$_EXTKEY] = array(
	'title' => 'User>Setup',
	'description' => 'Allows users to edit a limited set of options for their user profile, eg. preferred language and their name and email address.',
	'category' => 'module',
	'shy' => 1,
	'dependencies' => '',
	'conflicts' => '',
	'priority' => '',
	'loadOrder' => '',
	'module' => 'mod',
	'doNotLoadInFE' => 1,
	'state' => 'stable',
	'internal' => 0,
	'uploadfolder' => 0,
	'createDirs' => '',
	'modify_tables' => '',
	'clearCacheOnLoad' => 0,
	'lockType' => '',
	'author' => 'Kasper Skaarhoj',
	'author_email' => 'kasperYYYY@typo3.com',
	'author_company' => 'Curby Soft Multimedia',
	'CGLcompliance' => '',
	'CGLcompliance_note' => '',
	'version' => '1.0.0',
	'_md5_values_when_last_written' => 'a:23:{s:12:"ext_icon.gif";s:4:"84ad";s:14:"ext_tables.php";s:4:"4f59";s:21:"locallang_csh_mod.xml";s:4:"6ed5";s:18:"cshimages/lang.png";s:4:"ed5f";s:17:"cshimages/rte.png";s:4:"d3ae";s:20:"cshimages/setup1.png";s:4:"fc36";s:21:"cshimages/setup10.png";s:4:"f1c4";s:21:"cshimages/setup11.png";s:4:"b90e";s:21:"cshimages/setup12.png";s:4:"038e";s:20:"cshimages/setup2.png";s:4:"b1ef";s:20:"cshimages/setup3.png";s:4:"b4b8";s:20:"cshimages/setup4.png";s:4:"c79d";s:20:"cshimages/setup5.png";s:4:"d0a0";s:20:"cshimages/setup6.png";s:4:"c640";s:20:"cshimages/setup7.png";s:4:"3479";s:20:"cshimages/setup8.png";s:4:"404a";s:20:"cshimages/setup9.png";s:4:"37b9";s:13:"mod/clear.gif";s:4:"cc11";s:12:"mod/conf.php";s:4:"a8bf";s:13:"mod/index.php";s:4:"9ccd";s:17:"mod/locallang.xml";s:4:"5796";s:21:"mod/locallang_mod.xml";s:4:"395a";s:13:"mod/setup.gif";s:4:"6187";}',
	'constraints' => array(
		'depends' => array(
			'php' => '5.1.0-0.0.0',
			'typo3' => '4.4.0-0.0.0',
		),
		'conflicts' => array(
		),
		'suggests' => array(
		),
	),
	'suggests' => array(
	),
);

?>